==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ru.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "Couldn't establish a federated share." : "Не удалось установить межсерверный общий доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не удаётся установить межсерверный общий доступ, возможно неверный пароль.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запрос межсерверного общего доступа оправлен, вы получите приглашение. Проверьте свои уведомления.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не удалось установить межсерверный общий доступ, на другом сервере установлена устаревшая версия Nextcloud (версия 9.x или более ранняя).",
    "It is not allowed to send federated group shares from this server." : "Не допускается предоставление межсерверного общего доступа группам пользователей.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не удалось предоставить доступ к %1$s, так как этот ресурс уже доступен пользователю %2$s",
    "Not allowed to create a federated share to the same account" : "Запрещено создавать федеративный общий доступ к одной и той же учетной записи",
    "Federated shares require read permissions" : "Для федеративных ресурсов требуются разрешения на чтение",
    "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Не удалось предоставить доступ к «%1$s», не удалось найти %2$s. Возможно, сервер недоступен или использует самоподписанный сертификат.",
    "Could not find share" : "Не удалось найти общий ресурс",
    "Federated sharing" : "Общий доступ из федеративного хранилища",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Вы получили «{share}» в качестве удалённого ресурса от {user} (от имени {behalf})",
    "You received {share} as a remote share from {user}" : "Вы получили {share} в качестве удалённого ресурса от {user}",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Federated Cloud Sharing" : "Межсерверный обмен",
    "Sharing" : "Общий доступ",
    "Federated file sharing" : "Межсерверный обмен файлами",
    "Provide federated file sharing across servers" : "Приложение позволяет использовать межсерверный обмен файлами",
    "Unable to update federated files sharing config" : "Невозможно обновить конфигурацию общего доступа к федеративным файлам",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Настройте, как пользователи могут публиковать ресурсы между разными серверами. Сюда входят и общие ресурсы между пользователями на этом сервере, если они используют федеративное совместное использование.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Разрешить пользователям на этом сервере публиковать общие ресурсы на других серверах (этот параметр также разрешает доступ WebDAV к общим папкам)",
    "Allow people on this server to receive shares from other servers" : "Разрешить пользователям этого сервера принимать общие ресурсы с других серверов",
    "Allow people on this server to send shares to groups on other servers" : "Разрешить пользователям этого сервера предоставлять общий доступ  группам пользователей других серверов",
    "Allow people on this server to receive group shares from other servers" : "Разрешить пользователям этого сервера принимать общие ресурсы с других серверов, опубликованные для групп пользователей",
    "Search global and public address book for people" : "Искать пользователей в глобальной и открытой адресной книге",
    "Allow people to publish their data to a global and public address book" : "Разрешить пользователям этого сервера публиковать свои данные в глобальной и общедоступной адресной книге",
    "Trusted federation" : "Надежная федерация",
    "Automatically accept shares from trusted federated accounts and groups by default" : "По умолчанию автоматически принимать общие ресурсы от доверенных федеративных учетных записей и групп",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поделитесь со мной через мой #Nextcloud Federated Cloud ID, см. {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ",
    "Cloud ID copied to the clipboard" : "Идентификатор облака скопирован в буфер обмена",
    "Copy to clipboard" : "Копировать в буфер",
    "Clipboard not available. Please copy the cloud ID manually." : "Буфер обмена недоступен. Пожалуйста, скопируйте cloud ID вручную.",
    "Copied!" : "Скопировано!",
    "Federated Cloud" : "Федерация облачных хранилищ",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Вы можете предоставить общий доступ любому пользователю Nextcloud или других серверов и сервисов, совместимых с Open Cloud Mesh (OCM)! Просто введите его идентификатор федеративного облачного хранилища в диалоге предоставления общего доступа. Идентификатор указывается в виде «person@cloud.example.com».",
    "Your Federated Cloud ID" : "Ваш идентификатор в федеративном облаке",
    "Share it so your friends can share files with you:" : "Сообщите его друзьям, чтобы они могли поделиться с вами файлами:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (ранее Твиттер)",
    "formerly Twitter" : "ранее Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Добавить к себе на сайт",
    "Share with me via Nextcloud" : "Поделитесь со мной через Nextcloud",
    "HTML Code:" : "HTML код:",
    "Cancel" : "Отмена",
    "Add remote share" : "Добавить общий ресурс другого сервера",
    "Remote share" : "Общий ресурс другого сервера",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Вы хотите добавить удалённый общий каталог {name} из {owner}@{remote}?",
    "Remote share password" : "Пароль общего ресурса другого сервера",
    "Incoming share could not be processed" : "Не удалось обработать входящий общий доступ",
    "Clipboard is not available" : "Буфер обмена недоступен",
    "Your Federated Cloud ID:" : "Ваш ID в федерации облачных хранилищ:",
    "Twitter" : "Твиттер",
    "Diaspora" : "Diaspora"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ru.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "Couldn't establish a federated share." : "Не удалось установить межсерверный общий доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не удаётся установить межсерверный общий доступ, возможно неверный пароль.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запрос межсерверного общего доступа оправлен, вы получите приглашение. Проверьте свои уведомления.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не удалось установить межсерверный общий доступ, на другом сервере установлена устаревшая версия Nextcloud (версия 9.x или более ранняя).",
    "It is not allowed to send federated group shares from this server." : "Не допускается предоставление межсерверного общего доступа группам пользователей.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не удалось предоставить доступ к %1$s, так как этот ресурс уже доступен пользователю %2$s",
    "Not allowed to create a federated share to the same account" : "Запрещено создавать федеративный общий доступ к одной и той же учетной записи",
    "Federated shares require read permissions" : "Для федеративных ресурсов требуются разрешения на чтение",
    "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Не удалось предоставить доступ к «%1$s», не удалось найти %2$s. Возможно, сервер недоступен или использует самоподписанный сертификат.",
    "Could not find share" : "Не удалось найти общий ресурс",
    "Federated sharing" : "Общий доступ из федеративного хранилища",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Вы получили «{share}» в качестве удалённого ресурса от {user} (от имени {behalf})",
    "You received {share} as a remote share from {user}" : "Вы получили {share} в качестве удалённого ресурса от {user}",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Federated Cloud Sharing" : "Межсерверный обмен",
    "Sharing" : "Общий доступ",
    "Federated file sharing" : "Межсерверный обмен файлами",
    "Provide federated file sharing across servers" : "Приложение позволяет использовать межсерверный обмен файлами",
    "Unable to update federated files sharing config" : "Невозможно обновить конфигурацию общего доступа к федеративным файлам",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Настройте, как пользователи могут публиковать ресурсы между разными серверами. Сюда входят и общие ресурсы между пользователями на этом сервере, если они используют федеративное совместное использование.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Разрешить пользователям на этом сервере публиковать общие ресурсы на других серверах (этот параметр также разрешает доступ WebDAV к общим папкам)",
    "Allow people on this server to receive shares from other servers" : "Разрешить пользователям этого сервера принимать общие ресурсы с других серверов",
    "Allow people on this server to send shares to groups on other servers" : "Разрешить пользователям этого сервера предоставлять общий доступ  группам пользователей других серверов",
    "Allow people on this server to receive group shares from other servers" : "Разрешить пользователям этого сервера принимать общие ресурсы с других серверов, опубликованные для групп пользователей",
    "The lookup server is only available for global scale." : "Сервер поиска доступен только в глобальном масштабе.",
    "Search global and public address book for people" : "Искать пользователей в глобальной и открытой адресной книге",
    "Allow people to publish their data to a global and public address book" : "Разрешить пользователям этого сервера публиковать свои данные в глобальной и общедоступной адресной книге",
    "Trusted federation" : "Надежная федерация",
    "Automatically accept shares from trusted federated accounts and groups by default" : "По умолчанию автоматически принимать общие ресурсы от доверенных федеративных учетных записей и групп",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поделитесь со мной через мой #Nextcloud Federated Cloud ID, см. {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ",
    "Cloud ID copied to the clipboard" : "Идентификатор облака скопирован в буфер обмена",
    "Copy to clipboard" : "Копировать в буфер",
    "Clipboard not available. Please copy the cloud ID manually." : "Буфер обмена недоступен. Пожалуйста, скопируйте cloud ID вручную.",
    "Copied!" : "Скопировано!",
    "Federated Cloud" : "Федерация облачных хранилищ",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Вы можете предоставить общий доступ любому пользователю Nextcloud или других серверов и сервисов, совместимых с Open Cloud Mesh (OCM)! Просто введите его идентификатор федеративного облачного хранилища в диалоге предоставления общего доступа. Идентификатор указывается в виде «person@cloud.example.com».",
    "Your Federated Cloud ID" : "Ваш идентификатор в федеративном облаке",
    "Share it so your friends can share files with you:" : "Сообщите его друзьям, чтобы они могли поделиться с вами файлами:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (ранее Твиттер)",
    "formerly Twitter" : "ранее Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Добавить к себе на сайт",
    "Share with me via Nextcloud" : "Поделитесь со мной через Nextcloud",
    "HTML Code:" : "HTML код:",
    "Cancel" : "Отмена",
    "Add remote share" : "Добавить общий ресурс другого сервера",
    "Remote share" : "Общий ресурс другого сервера",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Вы хотите добавить удалённый общий каталог {name} из {owner}@{remote}?",
    "Remote share password" : "Пароль общего ресурса другого сервера",
    "Incoming share could not be processed" : "Не удалось обработать входящий общий доступ",
    "Clipboard is not available" : "Буфер обмена недоступен",
    "Your Federated Cloud ID:" : "Ваш ID в федерации облачных хранилищ:",
    "Twitter" : "Твиттер",
    "Diaspora" : "Diaspora"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
